@@ -97,9 +97,9 @@ class FS(object):
         :return: list of names, relative to ``path``.
         :rtype: list
 
-        :raises `fs.errors.DirectoryExpected`: If `path` is not a
+        :raises fs.errors.DirectoryExpected: If `path` is not a
             directory.
-        :raises `fs.errors.ResourceNotFound`: If `path` does not exist.
+        :raises fs.errors.ResourceNotFound: If `path` does not exist.
 
         This method will return a list of the resources in a directory.
         A 'resource' is a file, directory, or one of the other types
@@ -110,17 +110,18 @@ class FS(object):
     @abc.abstractmethod
     def makedir(self, path, permissions=None, recreate=False):
         """
-        Make a directory.
+        Make a directory, and return a :class:`~fs.subfs.SubFS` for
+        the new directory.
 
         :param str path: Path to directory from root.
         :param permissions: :class:`~fs.permissions.Permissions`
             instance.
         :type permissions: Permissions
-        :param recreate: Do not raise an error if the directory exists.
-        :type recreate: bool
+        :param bool recreate: Do not raise an error if the directory exists.
+        :rtype: :class:`~fs.subfs.SubFS`
 
-        :raises `fs.errors.DirectoryExists`: if the path already exists.
-        :raises `fs.errors.ResourceNotFound`: if the path is not found.
+        :raises fs.errors.DirectoryExists: if the path already exists.
+        :raises fs.errors.ResourceNotFound: if the path is not found.
 
         """
 
@@ -130,7 +131,9 @@ class FS(object):
         Open a binary file-like object.
 
         :param str path: A path on the filesystem.
-        :param str mode: Mode to open file.
+        :param str mode: Mode to open file (must be a valid non-text
+            mode). Since this method only opens binary files, the `b` in
+            the mode string is implied.
         :param buffering: Buffering policy (-1  to use default
             buffering, 0 to disable buffering, or positive integer to
             indicate buffer size).
@@ -139,6 +142,11 @@ class FS(object):
             information required by the filesystem (if any).
         :rtype: file object
 
+        :raises fs.errors.FileExpected: If the path is not a file.
+        :raises fs.errors.FileExists: If the file exists, and
+            *exclusive mode* is specified (`x` in the mode).
+        :raises fs.errors.ResourceNotFound: If `path` does not exist.
+
         """
 
     @abc.abstractmethod
@@ -148,8 +156,8 @@ class FS(object):
 
         :param str path: Path to the file you want to remove.
 
-        :raises `fs.errors.FileExpected`: if the path is a directory.
-        :raises `fs.errors.ResourceNotFound`: if the path does not
+        :raises fs.errors.FileExpected: if the path is a directory.
+        :raises fs.errors.ResourceNotFound: if the path does not
             exist.
 
         """
@@ -161,14 +169,15 @@ class FS(object):
 
         :param str path: Path of the directory to remove.
 
-        :raises `fs.errors.DirectoryNotEmpty`: If the directory is not
-            empty and force == ``False``
-        :raises `fs.errors.ParentDirectoryMissing`: If an intermediate
-            directory is missing
-        :raises `fs.errors.DirectoryExpected`: If the path is not a
-            directory
-        :raises `fs.errors.ResourceNotFound`: If the path does not
-            exist
+        :raises fs.errors.DirectoryNotEmpty: If the directory is not
+            empty (see :meth:`~fs.base.removetree` if you want to
+            remove the directory contents).
+        :raises fs.errors.DirectoryExpected: If the path is not a
+            directory.
+        :raises fs.errors.ResourceNotFound: If the path does not
+            exist.
+        :raises fs.errors.RemoveRootError: If an attempt is made to
+            remove the root directory (i.e. `'/'`).
         """
 
     @abc.abstractmethod
@@ -179,6 +188,9 @@ class FS(object):
         :param str path: Path to a resource on the filesystem.
         :param dict info: Dict of resource info.
 
+        :raises fs.errors.ResourceNotFound: If `path` does not exist
+            on the filesystem.
+
         This method is the compliment to :class:`~fs.base.getinfo` and is
         used to set info values on a resource.
 
@@ -207,8 +219,8 @@ class FS(object):
 
         :param str path: Path to a file.
         :param bytes data: Bytes to append.
-        :raises: `ValueError` if ``data`` is not bytes.
-        :raises: `fs.errors.ResourceNotFound` if a parent directory of
+        :raises ValueError: if ``data`` is not bytes.
+        :raises fs.errors.ResourceNotFound: if a parent directory of
             ``path`` does not exist.
 
         """
@@ -230,8 +242,8 @@ class FS(object):
 
         :param str path: Path to a file.
         :param str text: Text to append.
-        :raises: `ValueError` if ``text`` is not bytes.
-        :raises: `fs.errors.ResourceNotFound` if a parent directory of
+        :raises ValueError: if ``text`` is not bytes.
+        :raises fs.errors.ResourceNotFound: if a parent directory of
             ``path`` does not exist.
 
         """
@@ -278,9 +290,9 @@ class FS(object):
         :type src_path: str
         :param dst_path: Path to destination file.
         :type dst_path: str
-        :raises `fs.errors.DestinationExists`: If ``dst_path`` exists,
+        :raises fs.errors.DestinationExists: If ``dst_path`` exists,
             and overwrite == ``False``.
-        :raises `fs.errors.ResourceNotFound`: If a parent directory of
+        :raises fs.errors.ResourceNotFound: If a parent directory of
             ``dst_path`` does not exist.
 
         """
@@ -298,7 +310,7 @@ class FS(object):
         :param str dst_path: Destination directory.
         :param bool create: If ``True`` then ``src_path`` will be
             created if it doesn't already exist.
-        :raises `fs.errors.ResourceNotFound`: If the destination
+        :raises fs.errors.ResourceNotFound: If the destination
             directory does not exist, and ``create`` is not True.
 
         """
@@ -453,7 +465,7 @@ class FS(object):
         :returns: file contents
         :rtype: bytes
 
-        :raises `fs.errors.ResourceNotFound`: If ``path`` does not
+        :raises fs.errors.ResourceNotFound: If ``path`` does not
             exist.
 
         """
@@ -471,7 +483,7 @@ class FS(object):
         :param str errors: Unicode errors parameter.
         :param str newline: Newlines parameter.
         :returns: file contents.
-        :raises `fs.errors.ResourceNotFound`: If ``path`` does not
+        :raises fs.errors.ResourceNotFound: If ``path`` does not
             exist.
 
         """
@@ -558,7 +570,7 @@ class FS(object):
 
         :param str path: A path on the filesystem.
         :rtype: str
-        :raises NoSysPath: If there is no corresponding system path.
+        :raises fs.errors.NoSysPath: If there is no corresponding system path.
 
         A system path is one recognized by the OS, that may be used
         outside of PyFilesystem (in an application or a shell for
@@ -629,7 +641,7 @@ class FS(object):
             for ``purpose``.
         :returns: A URL.
         :rtype: str
-        :raises `fs.errors.NoURL`: If the path does not map to a URL.
+        :raises fs.errors.NoURL: If the path does not map to a URL.
 
         """
         raise errors.NoURL(path, purpose)
@@ -756,9 +768,9 @@ class FS(object):
         :returns: A sub-directory filesystem.
         :rtype: :class:`~fs.subfs.SubFS`
 
-        :raises `fs.errors.DirectoryExists`: if the path is already
+        :raises fs.errors.DirectoryExists: if the path is already
             a directory, and ``recreate`` is False.
-        :raises `fs.errors.DirectoryExpected`: if one of the ancestors
+        :raises fs.errors.DirectoryExpected: if one of the ancestors
             in the path isn't a directory.
 
         """
@@ -787,9 +799,9 @@ class FS(object):
             file will be written to.
         :param bool overwrite: If `True` destination path will be
             overwritten if it exists.
-        :raises `fs.errors.DestinationExists`: If ``dst_path`` exists,
+        :raises fs.errors.DestinationExists: If ``dst_path`` exists,
             and overwrite == ``False``.
-        :raises `fs.errors.ResourceNotFound`: If a parent directory of
+        :raises fs.errors.ResourceNotFound: If a parent directory of
             ``dst_path`` does not exist.
 
         """
@@ -831,12 +843,15 @@ class FS(object):
             buffering off, ``1`` to select line buffering, ``>1`` to
             select a fixed-size buffer, ``-1`` to auto-detect.
         :param str encoding: Encoding for text files (defaults to
-            ``utf-9``)
+            ``utf-8``)
         :param str errors: What to do with unicode decode errors (see
-            https://docs.python.org/3/library/codecs.html#error-
-            handlers)
-        :param str newline: New line parameter (See
-            https://docs.python.org/3/library/functions.html#open).
+            `stdlib docs <https://docs.python.org/3/library/codecs.html#error-handlers>`_)
+        :param str newline: New line parameter (See `stdlib docs
+            <https://docs.python.org/3/library/functions.html#open>`_)
+        :param options: Additional keyword parameters to set
+            implementation specific options (if required). See
+            implementation docs for details.
+
         :rtype: file object
         """
         validate_open_mode(mode)
@@ -860,7 +875,7 @@ class FS(object):
         :param str path: Path to a directory on the filesystem.
         :returns: A filesystem object representing a sub-directory.
         :rtype: :class:`~fs.subfs.SubFS`
-        :raises `fs.errors.DirectoryExpected`: If ``dst_path`` does not
+        :raises fs.errors.DirectoryExpected: If ``dst_path`` does not
             exist or is not a directory.
 
         """
@@ -1096,16 +1111,20 @@ class FS(object):
 
         :param str path: A path
         :returns: A normalized, absolute path.
-        :rtype str:
-        :raises `fs.errors.InvalidPath`: If the path is invalid.
-        :raises: :class:`~fs.errors.FilesystemClosed` if the filesystem
+        :rtype: str
+        :raises fs.errors.InvalidPath: If the path is invalid.
+        :raises fs.errors.FilesystemClosed: if the filesystem
             is closed.
 
         """
         self.check()
 
         if isinstance(path, bytes):
-            raise ValueError('path must not be bytes')
+            raise TypeError(
+                'paths must be unicode (not str)'
+                if six.PY2 else
+                'paths must be str (not bytes)'
+            )
 
         meta = self.getmeta()
 
@@ -1172,7 +1191,7 @@ class FS(object):
             filesystem is closed.
 
         :returns: None
-        :raises: :class:`~fs.errors.FilesystemClosed` if the filesystem
+        :raises fs.errors.FilesystemClosed: if the filesystem
             is closed.
 
         """
